@@ -21,12 +21,16 @@
 #include "docmetainfo.h"
 #include "navigator.h"
 #include "navigatorappitem.h"
+#include "navigatorappgroupitem.h"
 #include "navigatoritem.h"
+#include "khc_debug.h"
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <KDebug>
-#include <KIconLoader>
+
+#include <QIcon>
+
+#include <prefs.h>
 
 using namespace KHC;
 
@@ -51,28 +55,27 @@ PluginTraverser::PluginTraverser( Navigator *navigator, NavigatorItem *parent )
 void PluginTraverser::process( DocEntry *entry )
 {
   if ( !mListView && !mParentItem ) {
-    kDebug( 1400 ) << "ERROR! Neither mListView nor mParentItem is set.";
+    khcWarning() << "ERROR! Neither mListView nor mParentItem is set.";
     return;
   }
 
-  if ( !entry->docExists() && !mNavigator->showMissingDocs() )
+  if ( !entry->docExists() && !Prefs::showMissingDocs() )
     return;
 
-  if ( entry->khelpcenterSpecial() == QLatin1String("apps") ) {
-    NavigatorAppItem *appItem;
+  if ( entry->khelpcenterSpecial().isEmpty() ) {
+    if ( mListView )
+      mCurrentItem = new NavigatorAppItem( entry, mListView, mCurrentItem );
+    else
+      mCurrentItem = new NavigatorAppItem( entry, mParentItem, mCurrentItem );
+  } else if ( entry->khelpcenterSpecial() == QLatin1String("apps") ) {
+    NavigatorAppGroupItem *appItem;
     entry->setIcon( "kde" );
     if ( mListView )
-      appItem = new NavigatorAppItem( entry, mListView, mCurrentItem );
+      appItem = new NavigatorAppGroupItem( entry, mListView, mCurrentItem );
     else
-      appItem = new NavigatorAppItem( entry, mParentItem, mCurrentItem );
-    KConfigGroup cfg(KSharedConfig::openConfig(), "General");
-    appItem->setRelpath( cfg.readPathEntry( "AppsRoot", QString() ) );
+      appItem = new NavigatorAppGroupItem( entry, mParentItem, mCurrentItem );
+    appItem->setRelpath( Prefs::appsRoot() );
     mCurrentItem = appItem;
-  } else if ( entry->khelpcenterSpecial() == QLatin1String("scrollkeeper" )) {
-    if ( mParentItem ) {
-      mCurrentItem = mNavigator->insertScrollKeeperDocs( mParentItem, mCurrentItem );
-    }
-    return;
   } else {
     if ( mListView )
       mCurrentItem = new NavigatorItem( entry, mListView, mCurrentItem );
@@ -97,11 +100,13 @@ void PluginTraverser::process( DocEntry *entry )
       mNavigator->insertIOSlaveDocs( entry->khelpcenterSpecial(), mCurrentItem );
     } else if ( entry->khelpcenterSpecial() == QLatin1String("info") ) {
       mNavigator->insertInfoDocs( mCurrentItem );
+    } else if ( entry->khelpcenterSpecial() == QLatin1String("scrollkeeper") ) {
+      mNavigator->insertScrollKeeperDocs( mCurrentItem );
     } else {
       return;
     }
 // TODO: was contents2 -> needs to be changed to help-contents-alternate or similar
-    mCurrentItem->setIcon( 0, SmallIcon( QLatin1String("help-contents") ) );
+    mCurrentItem->setIcon( 0, QIcon::fromTheme( QLatin1String("help-contents") ) );
   }
 }
 
@@ -110,7 +115,7 @@ DocEntryTraverser *PluginTraverser::createChild( DocEntry * /*entry*/ )
   if ( mCurrentItem ) {
     return new PluginTraverser( mNavigator, mCurrentItem );
   }
-  kDebug( 1400 ) << "ERROR! mCurrentItem is not set.";
+  khcWarning() << "ERROR! mCurrentItem is not set.";
   return 0;
 }
 
